@@ -10,9 +10,10 @@ class AdminAuthenticationForm(AuthenticationForm):
     A custom authentication form used in the admin app.
     """
     error_messages = {
-        'invalid_login': _("Please enter the correct %(username)s and password "
-                           "for a staff account. Note that both fields may be "
-                           "case-sensitive."),
+        'invalid_login': _(
+            "Please enter the correct %(username)s and password for a staff "
+            "account. Note that both fields may be case-sensitive."
+        ),
     }
     required_css_class = 'required'
 
